Documentation
¶
Overview ¶
************************************************************************ * * Mayfair ICT * __________________ * * [2026] Mayfair ICT * All Rights Reserved. * * NOTICE: All information contained herein is, and remains * the property of Mayfair ICT and its suppliers, * if any. The intellectual and technical concepts contained * herein are proprietary to Mayfair ICT * and its suppliers and may be covered by U.S. and Foreign Patents, * patents in process, and are protected by trade secret or copyright law. * Dissemination of this information or reproduction of this material * is strictly forbidden unless prior written permission is obtained * from Mayfair ICT.
* * Frank Willem Mulder * __________________ * * Copyright 2026 Frank Willem Mulder. All rights reserved. * Use of this source code is governed license that can be found in the LICENSE file.
* * Frank Willem Mulder * __________________ * * Copyright 2026 Frank Willem Mulder. All rights reserved. * Use of this source code is governed license that can be found in the LICENSE file.
* * Frank Willem Mulder * __________________ * * Copyright 2026 Frank Willem Mulder. All rights reserved. * Use of this source code is governed license that can be found in the LICENSE file.
Index ¶
- type Container
- type Index
- func (ix *Index[K, V]) Delete1(k K) ot.TransactionType
- func (ix *Index[K, V]) Delete2(k1 K, k2 K) ot.TransactionType
- func (ix *Index[K, V]) DeleteN(ks []K) ot.TransactionType
- func (ix *Index[K, V]) Get1(k K) (V, bool)
- func (ix *Index[K, V]) Get2(k1 K, k2 K) (V, bool)
- func (ix *Index[K, V]) GetN(ks []K) (V, bool)
- func (ix *Index[K, V]) IsTerminal() bool
- func (ix *Index[K, V]) Query(ks []K) []V
- func (ix *Index[K, V]) Search(kso []K, v V) ([]K, bool)
- func (ix *Index[K, V]) Size() int
- func (ix *Index[K, V]) String() string
- type InvMapAll
- type InvMapOne
- type KeyStack
- type MultiKeyMapStore
- func (mm *MultiKeyMapStore[K, V]) Clear()
- func (mm *MultiKeyMapStore[K, V]) Delete1(k K) (V, ot.TransactionType)
- func (mm *MultiKeyMapStore[K, V]) Delete2(k1 K, k2 K) (V, ot.TransactionType)
- func (mm *MultiKeyMapStore[K, V]) DeleteN(ks []K) (V, ot.TransactionType)
- func (mm *MultiKeyMapStore[K, V]) Get1(k K) (V, bool)
- func (mm *MultiKeyMapStore[K, V]) Get2(k1 K, k2 K) (V, bool)
- func (mm *MultiKeyMapStore[K, V]) GetN(ks []K) (V, bool)
- func (mm *MultiKeyMapStore[K, V]) InverseMapAll() InvMapAll[K, V]
- func (mm *MultiKeyMapStore[K, V]) InverseMapOne(v V) InvMapOne[K, V]
- func (mm *MultiKeyMapStore[K, V]) IsEmpty() bool
- func (mm *MultiKeyMapStore[K, V]) Put1(k K, v V) ot.TransactionType
- func (mm *MultiKeyMapStore[K, V]) Put2(k1 K, k2 K, v V) ot.TransactionType
- func (mm *MultiKeyMapStore[K, V]) PutN(ks []K, v V) ot.TransactionType
- func (mm *MultiKeyMapStore[K, V]) Query() []V
- func (mm *MultiKeyMapStore[K, V]) Query1(k1 K) []V
- func (mm *MultiKeyMapStore[K, V]) Query2(k1 K, k2 K) []V
- func (mm *MultiKeyMapStore[K, V]) Query3(k1 K, k2 K, k3 K) []V
- func (mm *MultiKeyMapStore[K, V]) QueryN(ks []K) []V
- func (mm *MultiKeyMapStore[K, V]) Size() int
- func (mm *MultiKeyMapStore[K, V]) String() string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Index ¶
type Index[K comparable, V comparable] struct { // contains filtered or unexported fields }
func (*Index[K, V]) Delete1 ¶
func (ix *Index[K, V]) Delete1(k K) ot.TransactionType
func (*Index[K, V]) Delete2 ¶
func (ix *Index[K, V]) Delete2(k1 K, k2 K) ot.TransactionType
func (*Index[K, V]) DeleteN ¶
func (ix *Index[K, V]) DeleteN(ks []K) ot.TransactionType
func (*Index[K, V]) IsTerminal ¶
type InvMapAll ¶
type InvMapAll[K comparable, V comparable] struct { // contains filtered or unexported fields }
type InvMapOne ¶
type InvMapOne[K comparable, V comparable] struct { // contains filtered or unexported fields }
type MultiKeyMapStore ¶
type MultiKeyMapStore[K comparable, V comparable] struct { // contains filtered or unexported fields }
func NewMultiKeyMapStore ¶
func NewMultiKeyMapStore[K comparable, V comparable]() *MultiKeyMapStore[K, V]
func (*MultiKeyMapStore[K, V]) Clear ¶
func (mm *MultiKeyMapStore[K, V]) Clear()
func (*MultiKeyMapStore[K, V]) Delete1 ¶
func (mm *MultiKeyMapStore[K, V]) Delete1(k K) (V, ot.TransactionType)
func (*MultiKeyMapStore[K, V]) Delete2 ¶
func (mm *MultiKeyMapStore[K, V]) Delete2(k1 K, k2 K) (V, ot.TransactionType)
func (*MultiKeyMapStore[K, V]) DeleteN ¶
func (mm *MultiKeyMapStore[K, V]) DeleteN(ks []K) (V, ot.TransactionType)
func (*MultiKeyMapStore[K, V]) Get1 ¶
func (mm *MultiKeyMapStore[K, V]) Get1(k K) (V, bool)
func (*MultiKeyMapStore[K, V]) Get2 ¶
func (mm *MultiKeyMapStore[K, V]) Get2(k1 K, k2 K) (V, bool)
func (*MultiKeyMapStore[K, V]) GetN ¶
func (mm *MultiKeyMapStore[K, V]) GetN(ks []K) (V, bool)
func (*MultiKeyMapStore[K, V]) InverseMapAll ¶
func (mm *MultiKeyMapStore[K, V]) InverseMapAll() InvMapAll[K, V]
func (*MultiKeyMapStore[K, V]) InverseMapOne ¶
func (mm *MultiKeyMapStore[K, V]) InverseMapOne(v V) InvMapOne[K, V]
func (*MultiKeyMapStore[K, V]) IsEmpty ¶
func (mm *MultiKeyMapStore[K, V]) IsEmpty() bool
func (*MultiKeyMapStore[K, V]) Put1 ¶
func (mm *MultiKeyMapStore[K, V]) Put1(k K, v V) ot.TransactionType
func (*MultiKeyMapStore[K, V]) Put2 ¶
func (mm *MultiKeyMapStore[K, V]) Put2(k1 K, k2 K, v V) ot.TransactionType
func (*MultiKeyMapStore[K, V]) PutN ¶
func (mm *MultiKeyMapStore[K, V]) PutN(ks []K, v V) ot.TransactionType
func (*MultiKeyMapStore[K, V]) Query ¶
func (mm *MultiKeyMapStore[K, V]) Query() []V
func (*MultiKeyMapStore[K, V]) Query1 ¶
func (mm *MultiKeyMapStore[K, V]) Query1(k1 K) []V
func (*MultiKeyMapStore[K, V]) Query2 ¶
func (mm *MultiKeyMapStore[K, V]) Query2(k1 K, k2 K) []V
func (*MultiKeyMapStore[K, V]) Query3 ¶
func (mm *MultiKeyMapStore[K, V]) Query3(k1 K, k2 K, k3 K) []V
func (*MultiKeyMapStore[K, V]) QueryN ¶
func (mm *MultiKeyMapStore[K, V]) QueryN(ks []K) []V
func (*MultiKeyMapStore[K, V]) Size ¶
func (mm *MultiKeyMapStore[K, V]) Size() int
func (*MultiKeyMapStore[K, V]) String ¶
func (mm *MultiKeyMapStore[K, V]) String() string